@@ -42,6 +42,7 @@ __all__ = (
     "PreserveDeletedFilesType",
     "PreserveDevicesType",
     "S3StorageClassType",
+    "SmbSecurityDescriptorCopyFlagsType",
     "SmbVersionType",
     "TaskExecutionStatusType",
     "TaskFilterNameType",
@@ -94,6 +95,7 @@ S3StorageClassType = Literal[
     "STANDARD",
     "STANDARD_IA",
 ]
+SmbSecurityDescriptorCopyFlagsType = Literal["NONE", "OWNER_DACL", "OWNER_DACL_SACL"]
 SmbVersionType = Literal["AUTOMATIC", "SMB2", "SMB3"]
 TaskExecutionStatusType = Literal[
     "ERROR", "LAUNCHING", "PREPARING", "QUEUED", "SUCCESS", "TRANSFERRING", "VERIFYING"
