@@ -32,6 +32,7 @@ from .literals import (
     PreserveDeletedFilesType,
     PreserveDevicesType,
     S3StorageClassType,
+    SmbSecurityDescriptorCopyFlagsType,
     SmbVersionType,
     TaskExecutionStatusType,
     TaskFilterNameType,
@@ -413,6 +414,7 @@ OptionsTypeDef = TypedDict(
         "TaskQueueing": TaskQueueingType,
         "LogLevel": LogLevelType,
         "TransferMode": TransferModeType,
+        "SecurityDescriptorCopyFlags": SmbSecurityDescriptorCopyFlagsType,
     },
     total=False,
 )
